@@ -143,13 +143,21 @@ class Install(InstallPlugin):
                 shutil.rmtree('/target/var/lib/mysql')
                 shutil.copytree('/var/lib/mysql','/target/var/lib')
 
-            #Setup database
+            #Setup sql server
+            subprocess.call(['sysctl', '-w', 'kernel.yama.protected_nonaccess_hardlinks=0'])
             install_misc.reconfigure(self.target, 'mysql-server-5.1')
+
+            #upstart managed chroot job, 
+            #we need stuff working INSIDE the chroot.
+            subprocess.call(['chroot', self.target, 'stop', 'mysql'])
             proc=subprocess.Popen(['chroot',self.target,'mysqld'])
+
+            #build database
             install_misc.reconfigure(self.target, 'mythtv-database')
 
             #Cleanup
             install_misc.chrex(self.target,'mysqladmin','--defaults-file=/etc/mysql/debian.cnf','shutdown')
+            subprocess.call(['sysctl', '-w', 'kernel.yama.protected_nonaccess_hardlinks=1'])
             proc.communicate()
 
             #Mythweb
